import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { ChaikinVolatilityIndicator } from "./ChaikinVolatilityIndicator";
/**
 * Represents a IgxDataChartComponent Chaikin Volatility indicator series.
 * The ChaikinVolatility indicator attempts to show volatility by displaying the spread between
 * the high and low values.
 * Default required members: High, Low
*/
export class IgrChaikinVolatilityIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new ChaikinVolatilityIndicator();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the moving average period for the current ChaikinVolatilityIndicator object.
     * The typical, and initial, value for ChaikinVolatilityIndicator periods is 10.
    *
    * Set the `period` property if you wish to change the moving average period for the indicator.
    *
    * ```html
    * <igx-data-chart [dataSource]="data">
    *   <igx-category-x-axis #xAxis
    *     label="time">
    *   </igx-category-x-axis>
    *   <igx-numeric-y-axis #yAxis>
    *   </igx-numeric-y-axis>
    *
    *   <igx-chaikin-volatility-indicator
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     openMemberPath="open"
    *     highMemberPath="high"
    *     lowMemberPath="low"
    *     closeMemberPath="close"
    *     volumeMemberPath="volume"
    *     period="30">
    *   </igx-chaikin-volatility-indicator>
    * </igx-data-chart>
    * ```
    */
    get period() {
        return this.i.qo;
    }
    set period(v) {
        this.i.qo = +v;
    }
}
