import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrSeries } from "./igr-series";
import { HighDensityScatterSeries } from "./HighDensityScatterSeries";
import { ensureBool, colorToString, stringToColor, toPoint } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent series where a high volume of scatter points can be displayed.
*/
export class IgrHighDensityScatterSeries extends IgrSeries {
    createImplementation() {
        return new HighDensityScatterSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Checks if this series is a scatter series
    */
    get isScatter() {
        return this.i.c4;
    }
    /**
     * Gets or sets the effective x-axis for the current object.
    */
    get xAxis() {
        if (this.i.ly == null) {
            return null;
        }
        if (!this.i.ly.externalObject) {
            let e = new IgrNumericXAxis(null);
            e._implementation = this.i.ly;
            this.i.ly.externalObject = e;
        }
        return this.i.ly.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.ly = null : this.i.ly = v.i;
    }
    /**
     * Gets or sets the effective y-axis for the current object.
    */
    get yAxis() {
        if (this.i.l0 == null) {
            return null;
        }
        if (!this.i.l0.externalObject) {
            let e = new IgrNumericYAxis(null);
            e._implementation = this.i.l0;
            this.i.l0.externalObject = e;
        }
        return this.i.l0.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.l0 = null : this.i.l0 = v.i;
    }
    /**
     * Gets or sets the x value mapping property for the current series object.
    */
    get xMemberPath() {
        return this.i.nu;
    }
    set xMemberPath(v) {
        this.i.nu = v;
    }
    /**
     * Gets or sets the y value mapping property for the current series object.
    */
    get yMemberPath() {
        return this.i.ny;
    }
    set yMemberPath(v) {
        this.i.ny = v;
    }
    /**
     * Gets or sets the whether to use use brute force mode.
    */
    get useBruteForce() {
        return this.i.me;
    }
    set useBruteForce(v) {
        this.i.me = ensureBool(v);
    }
    /**
     * Gets or sets the whether to progressively load the data into the chart.
    */
    get progressiveLoad() {
        return this.i.md;
    }
    set progressiveLoad(v) {
        this.i.md = ensureBool(v);
    }
    /**
     * Gets or sets the density value that maps to the minimum heat color.
    */
    get heatMinimum() {
        return this.i.m6;
    }
    set heatMinimum(v) {
        this.i.m6 = +v;
    }
    /**
     * Gets or sets the value that maps to the maximum heat color.
    */
    get heatMaximum() {
        return this.i.m5;
    }
    set heatMaximum(v) {
        this.i.m5 = +v;
    }
    /**
     * Gets or sets the color to use for the minimum end of the scale.
    */
    get heatMinimumColor() {
        return colorToString(this.i.or);
    }
    set heatMinimumColor(v) {
        this.i.or = stringToColor(v);
    }
    /**
     * Gets or sets the color to use for the maximum end of the scale.
    */
    get heatMaximumColor() {
        return colorToString(this.i.oq);
    }
    set heatMaximumColor(v) {
        this.i.oq = stringToColor(v);
    }
    /**
     * Gets or sets the the pixel extent of the square data points that are rendered.
    */
    get pointExtent() {
        return this.i.ni;
    }
    set pointExtent(v) {
        this.i.ni = +v;
    }
    /**
     * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
    */
    get progressiveStatus() {
        return this.i.nj;
    }
    set progressiveStatus(v) {
        this.i.nj = +v;
    }
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis) {
        let iv = this.i.mc(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis) {
        let iv = this.i.mb(axis);
        return (iv);
    }
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item) {
        let iv = this.i.c7(item);
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world) {
        let iv = this.i.fl(toPoint(world));
        return (iv);
    }
}
