import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { MoneyFlowIndexIndicator } from "./MoneyFlowIndexIndicator";
/**
 * Represents a IgxDataChartComponent Money Flow Index indicator series.
 * Default required members: Close, Low, High, Volume
*
* Represents a Ignite UIDataChart Money Flow Index indicator series.
*
* Example:
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
* 	<igx-money-flow-index-indicator
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
* 		openMemberPath="open"
*         highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close"
* 		volumeMemberPath="volume">
*     </igx-money-flow-index-indicator>
* </igx-data-chart>
* ```
*/
export declare class IgrMoneyFlowIndexIndicator extends IgrStrategyBasedIndicator<IIgrMoneyFlowIndexIndicatorProps> {
    protected createImplementation(): MoneyFlowIndexIndicator;
    readonly i: MoneyFlowIndexIndicator;
    constructor(props: IIgrMoneyFlowIndexIndicatorProps);
    /**
     * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
     * The typical, and initial, value for MoneyFlowIndexIndicator periods is 14.
    *
    * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-money-flow-index-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		period="14">
    *     </igx-money-flow-index-indicator>
    * </igx-data-chart>
    * ```
    */
    period: number;
}
export interface IIgrMoneyFlowIndexIndicatorProps extends IIgrStrategyBasedIndicatorProps {
    /**
     * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
     * The typical, and initial, value for MoneyFlowIndexIndicator periods is 14.
    *
    * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-money-flow-index-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		period="14">
    *     </igx-money-flow-index-indicator>
    * </igx-data-chart>
    * ```
    */
    period?: number | string;
}
