import { IgrStraightNumericAxisBase } from "./igr-straight-numeric-axis-base";
import { NumericYAxis } from "./NumericYAxis";
/**
 * Represents a IgxDataChartComponent numeric Y axis.
*
* The `IgxNumericYAxisComponent` treats the data as continuously varying numerical data items. Labels on this axis are placed along the Y-axis. Location of labels varies according to the value in a data column that is mapped using the `YMemberPath` property for Scatter Series or `ValueMemberPath` property for Category Series.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-column-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-column-series>
* </igx-data-chart>
* ```
*/
export class IgrNumericYAxis extends IgrStraightNumericAxisBase {
    constructor(props) {
        super(props);
    }
    createImplementation() {
        return new NumericYAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
     * Gets if the current axis is of vertical axis
    */
    get isVertical() {
        return this.i.ce;
    }
    scrollRangeIntoView(minimum, maximum) {
        this.i.lo(minimum, maximum);
    }
}
