import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrSeries } from "./igr-series";
/**
 * Series class for rendering polygons.
*/
export class IgrShapeSeriesBase extends IgrSeries {
    constructor(props) {
        super(props);
    }
    get i() {
        return this._implementation;
    }
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    get shapeMemberPath() {
        return this.i.mj;
    }
    set shapeMemberPath(v) {
        this.i.mj = v;
    }
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    get xAxis() {
        if (this.i.lx == null) {
            return null;
        }
        if (!this.i.lx.externalObject) {
            let e = new IgrNumericXAxis(null);
            e._implementation = this.i.lx;
            this.i.lx.externalObject = e;
        }
        return this.i.lx.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.lx = null : this.i.lx = v.i;
    }
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    get yAxis() {
        if (this.i.lz == null) {
            return null;
        }
        if (!this.i.lz.externalObject) {
            let e = new IgrNumericYAxis(null);
            e._implementation = this.i.lz;
            this.i.lz.externalObject = e;
        }
        return this.i.lz.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.lz = null : this.i.lz = v.i;
    }
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    get shapeFilterResolution() {
        return this.i.me;
    }
    set shapeFilterResolution(v) {
        this.i.me = +v;
    }
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis) {
        let iv = this.i.l4(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis) {
        let iv = this.i.l3(axis);
        return (iv);
    }
}
