import { SplineType } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { SplineSeriesBase } from "./SplineSeriesBase";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export declare abstract class IgrSplineSeriesBase<P extends IIgrSplineSeriesBaseProps = IIgrSplineSeriesBaseProps> extends IgrHorizontalAnchoredCategorySeries<P> {
    readonly i: SplineSeriesBase;
    constructor(props: P);
    /**
     * Gets whether the current series shows an area or line shape.
    */
    readonly isAreaOrLine: boolean;
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-spline-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         splineType="clamped"
    *         valueMemberPath="value">
    *     </igx-spline-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    */
    splineType: SplineType;
}
export interface IIgrSplineSeriesBaseProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-spline-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         splineType="clamped"
    *         valueMemberPath="value">
    *     </igx-spline-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    */
    splineType?: SplineType | string;
}
