import { SplineType_$type } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export class IgrSplineSeriesBase extends IgrHorizontalAnchoredCategorySeries {
    constructor(props) {
        super(props);
    }
    get i() {
        return this._implementation;
    }
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine() {
        return this.i.ck;
    }
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-spline-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         splineType="clamped"
    *         valueMemberPath="value">
    *     </igx-spline-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    */
    get splineType() {
        return this.i.qa;
    }
    set splineType(v) {
        this.i.qa = ensureEnum(SplineType_$type, v);
    }
}
