import * as React from 'react';
import { TimeAxisBreak } from "./TimeAxisBreak";
/**
 * Settings for breaks on a time axis.
 * Axis breaks can be added to a time axis in order to omit portions of time on that axis.  For example, weekends can be skipped, if they are not relevant to your data.
*/
export declare class IgrTimeAxisBreak<P extends IIgrTimeAxisBreakProps = IIgrTimeAxisBreakProps> extends React.Component<P, {}> {
    protected createImplementation(): TimeAxisBreak;
    protected _implementation: any;
    readonly i: TimeAxisBreak;
    private onImplementationCreated;
    constructor(props: P);
    private _hasUserValues;
    protected readonly hasUserValues: Set<string>;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * The start time of the axis break.
    */
    start: Date;
    /**
     * The end time of the axis break.
    */
    end: Date;
    /**
     * The interval at which to repeat this break, expressed as a TimeSpan.
    */
    interval: number;
}
export interface IIgrTimeAxisBreakProps {
    /**
     * The start time of the axis break.
    */
    start?: Date;
    /**
     * The end time of the axis break.
    */
    end?: Date;
    /**
     * The interval at which to repeat this break, expressed as a TimeSpan.
    */
    interval?: number | string;
}
