import * as React from 'react';
import { TimeAxisIntervalType } from "./TimeAxisIntervalType";
import { TimeAxisInterval } from "./TimeAxisInterval";
/**
 * Settings for an interval on a time axis.
 * Label intervals can be applied to a time axis, which are dynamic, according to the visible range.  During zooming, the visible range of the axis can change, and so a different interval is selected.  The interval selected will be the one with the largest range smaller than the visible range of the axis.
*/
export declare class IgrTimeAxisInterval<P extends IIgrTimeAxisIntervalProps = IIgrTimeAxisIntervalProps> extends React.Component<P, {}> {
    protected createImplementation(): TimeAxisInterval;
    protected _implementation: any;
    readonly i: TimeAxisInterval;
    private onImplementationCreated;
    constructor(props: P);
    private _hasUserValues;
    protected readonly hasUserValues: Set<string>;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * The visible axis range at which to apply this interval.
    */
    range: number;
    /**
     * The interval, expressed as a multiple of IntervalType.
    */
    interval: number;
    /**
     * The unit of time for this interval.
    */
    intervalType: TimeAxisIntervalType;
}
export interface IIgrTimeAxisIntervalProps {
    /**
     * The visible axis range at which to apply this interval.
    */
    range?: number | string;
    /**
     * The interval, expressed as a multiple of IntervalType.
    */
    interval?: number | string;
    /**
     * The unit of time for this interval.
    */
    intervalType?: TimeAxisIntervalType | string;
}
