import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { ChaikinVolatilityIndicator } from "./ChaikinVolatilityIndicator";
/**
 * Represents a IgxDataChartComponent Chaikin Volatility indicator series.
 * The ChaikinVolatility indicator attempts to show volatility by displaying the spread between
 * the high and low values.
 * Default required members: High, Low
*/
var IgrChaikinVolatilityIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrChaikinVolatilityIndicator, _super);
    function IgrChaikinVolatilityIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrChaikinVolatilityIndicator.prototype.createImplementation = function () {
        return new ChaikinVolatilityIndicator();
    };
    Object.defineProperty(IgrChaikinVolatilityIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrChaikinVolatilityIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current ChaikinVolatilityIndicator object.
         * The typical, and initial, value for ChaikinVolatilityIndicator periods is 10.
        *
        * Set the `period` property if you wish to change the moving average period for the indicator.
        *
        * ```html
        * <igx-data-chart [dataSource]="data">
        *   <igx-category-x-axis #xAxis
        *     label="time">
        *   </igx-category-x-axis>
        *   <igx-numeric-y-axis #yAxis>
        *   </igx-numeric-y-axis>
        *
        *   <igx-chaikin-volatility-indicator
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     openMemberPath="open"
        *     highMemberPath="high"
        *     lowMemberPath="low"
        *     closeMemberPath="close"
        *     volumeMemberPath="volume"
        *     period="30">
        *   </igx-chaikin-volatility-indicator>
        * </igx-data-chart>
        * ```
        */
        get: function () {
            return this.i.qo;
        },
        set: function (v) {
            this.i.qo = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrChaikinVolatilityIndicator;
}(IgrStrategyBasedIndicator));
export { IgrChaikinVolatilityIndicator };
