import * as tslib_1 from "tslib";
import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrSeries } from "./igr-series";
import { HighDensityScatterSeries } from "./HighDensityScatterSeries";
import { ensureBool, colorToString, stringToColor, toPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent series where a high volume of scatter points can be displayed.
*/
var IgrHighDensityScatterSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrHighDensityScatterSeries, _super);
    function IgrHighDensityScatterSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrHighDensityScatterSeries.prototype.createImplementation = function () {
        return new HighDensityScatterSeries();
    };
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "isScatter", {
        /**
         * Checks if this series is a scatter series
        */
        get: function () {
            return this.i.c4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "xAxis", {
        /**
         * Gets or sets the effective x-axis for the current object.
        */
        get: function () {
            if (this.i.ly == null) {
                return null;
            }
            if (!this.i.ly.externalObject) {
                var e = new IgrNumericXAxis(null);
                e._implementation = this.i.ly;
                this.i.ly.externalObject = e;
            }
            return this.i.ly.externalObject;
        },
        set: function (v) {
            v == null ? this.i.ly = null : this.i.ly = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "yAxis", {
        /**
         * Gets or sets the effective y-axis for the current object.
        */
        get: function () {
            if (this.i.l0 == null) {
                return null;
            }
            if (!this.i.l0.externalObject) {
                var e = new IgrNumericYAxis(null);
                e._implementation = this.i.l0;
                this.i.l0.externalObject = e;
            }
            return this.i.l0.externalObject;
        },
        set: function (v) {
            v == null ? this.i.l0 = null : this.i.l0 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "xMemberPath", {
        /**
         * Gets or sets the x value mapping property for the current series object.
        */
        get: function () {
            return this.i.nu;
        },
        set: function (v) {
            this.i.nu = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "yMemberPath", {
        /**
         * Gets or sets the y value mapping property for the current series object.
        */
        get: function () {
            return this.i.ny;
        },
        set: function (v) {
            this.i.ny = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "useBruteForce", {
        /**
         * Gets or sets the whether to use use brute force mode.
        */
        get: function () {
            return this.i.me;
        },
        set: function (v) {
            this.i.me = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "progressiveLoad", {
        /**
         * Gets or sets the whether to progressively load the data into the chart.
        */
        get: function () {
            return this.i.md;
        },
        set: function (v) {
            this.i.md = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "heatMinimum", {
        /**
         * Gets or sets the density value that maps to the minimum heat color.
        */
        get: function () {
            return this.i.m6;
        },
        set: function (v) {
            this.i.m6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "heatMaximum", {
        /**
         * Gets or sets the value that maps to the maximum heat color.
        */
        get: function () {
            return this.i.m5;
        },
        set: function (v) {
            this.i.m5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "heatMinimumColor", {
        /**
         * Gets or sets the color to use for the minimum end of the scale.
        */
        get: function () {
            return colorToString(this.i.or);
        },
        set: function (v) {
            this.i.or = stringToColor(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "heatMaximumColor", {
        /**
         * Gets or sets the color to use for the maximum end of the scale.
        */
        get: function () {
            return colorToString(this.i.oq);
        },
        set: function (v) {
            this.i.oq = stringToColor(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "pointExtent", {
        /**
         * Gets or sets the the pixel extent of the square data points that are rendered.
        */
        get: function () {
            return this.i.ni;
        },
        set: function (v) {
            this.i.ni = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrHighDensityScatterSeries.prototype, "progressiveStatus", {
        /**
         * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
        */
        get: function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    IgrHighDensityScatterSeries.prototype.canUseAsYAxis = function (axis) {
        var iv = this.i.mc(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    IgrHighDensityScatterSeries.prototype.canUseAsXAxis = function (axis) {
        var iv = this.i.mb(axis);
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrHighDensityScatterSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c7(item);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrHighDensityScatterSeries.prototype.getItem = function (world) {
        var iv = this.i.fl(toPoint(world));
        return (iv);
    };
    return IgrHighDensityScatterSeries;
}(IgrSeries));
export { IgrHighDensityScatterSeries };
