import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { PointSeries } from "./PointSeries";
/**
 * Represents a IgxDataChartComponent point series.
*
* You can use the `IgxPointSeriesComponent` plot a value along a category or date.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis
* 		#yAxis>
*     <igx-numeric-y-axis>
*     </igx-numeric-y-axis>
*     <igx-point-series
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		valueMemberPath="coal">
*     </igx-point-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxPointSeriesComponent = new IgxPointSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath = "coal";
* this.chart.series.add(series);
* ```
*/
export declare class IgrPointSeries extends IgrHorizontalAnchoredCategorySeries<IIgrPointSeriesProps> {
    protected createImplementation(): PointSeries;
    readonly i: PointSeries;
    constructor(props: IIgrPointSeriesProps);
    /**
     * Overridden by derived series classes to indicate when markerless display is preferred or not.
    */
    readonly isMarkerlessDisplayPreferred: boolean;
}
export interface IIgrPointSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
}
