import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { PositiveVolumeIndexIndicator } from "./PositiveVolumeIndexIndicator";
/**
 * Represents a IgxDataChartComponent Positive Volume Index (PVI) indicator series.
 * Default required members: Close, Volume
*
* You can use the `IgxPositiveVolumeIndexIndicatorComponent` with the 'NegativeVolumeIndexIndicator' to identify bull markets.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-positive-volume-index-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-positive-volume-index-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxPositiveVolumeIndexIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgrPositiveVolumeIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrPositiveVolumeIndexIndicator, _super);
    function IgrPositiveVolumeIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrPositiveVolumeIndexIndicator.prototype.createImplementation = function () {
        return new PositiveVolumeIndexIndicator();
    };
    Object.defineProperty(IgrPositiveVolumeIndexIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return IgrPositiveVolumeIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrPositiveVolumeIndexIndicator };
