import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { PriceVolumeTrendIndicator } from "./PriceVolumeTrendIndicator";
/**
 * Represents a IgxDataChartComponent Price Volume Trend Indicator series.
 * Default required members: Volume, Close
*
* You can use the `IgxPriceVolumeTrendIndicatorComponent` to measure money flow by adding or subtracting a portion of the daily volume.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-price-volume-trend-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-price-volume-trend-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxPriceVolumeTrendIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgrPriceVolumeTrendIndicator extends IgrStrategyBasedIndicator<IIgrPriceVolumeTrendIndicatorProps> {
    protected createImplementation(): PriceVolumeTrendIndicator;
    readonly i: PriceVolumeTrendIndicator;
    constructor(props: IIgrPriceVolumeTrendIndicatorProps);
}
export interface IIgrPriceVolumeTrendIndicatorProps extends IIgrStrategyBasedIndicatorProps {
}
