import { NumericScaleMode } from "./NumericScaleMode";
import { IgrNumericAxisBase, IIgrNumericAxisBaseProps } from "./igr-numeric-axis-base";
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
/**
 * Defines a set of basic methods and properties used to create a StraightNumeric axis.
*/
export declare abstract class IgrStraightNumericAxisBase<P extends IIgrStraightNumericAxisBaseProps = IIgrStraightNumericAxisBaseProps> extends IgrNumericAxisBase<P> {
    readonly i: StraightNumericAxisBase;
    constructor(props: P);
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis
    *         scaleMode="logarithmic">
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    */
    scaleMode: NumericScaleMode;
}
export interface IIgrStraightNumericAxisBaseProps extends IIgrNumericAxisBaseProps {
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis
    *         scaleMode="logarithmic">
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    */
    scaleMode?: NumericScaleMode | string;
}
