import * as React from 'react';
import { TimeAxisLabelFormat } from "./TimeAxisLabelFormat";
/**
 * Settings for a label format on a time axis.
 * Label formats can be applied to a time axis, which are dynamic, according to the visible range.  During zooming, the visible range of the axis can change, and so a different label format is selected.  The label format selected will be the one with the largest range smaller than the visible range of the axis.
*/
export declare class IgrTimeAxisLabelFormat<P extends IIgrTimeAxisLabelFormatProps = IIgrTimeAxisLabelFormatProps> extends React.Component<P, {}> {
    protected createImplementation(): TimeAxisLabelFormat;
    protected _implementation: any;
    readonly i: TimeAxisLabelFormat;
    private onImplementationCreated;
    constructor(props: P);
    private _hasUserValues;
    protected readonly hasUserValues: Set<string>;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * The visible axis range at which to apply this label format.
    */
    range: number;
    /**
     * The DateTime format string to apply.
     * Some common DateTime format strings are: yyyy, MM/dd/yy, and hh:mm:ss.
    */
    format: string;
}
export interface IIgrTimeAxisLabelFormatProps {
    /**
     * The visible axis range at which to apply this label format.
    */
    range?: number | string;
    /**
     * The DateTime format string to apply.
     * Some common DateTime format strings are: yyyy, MM/dd/yy, and hh:mm:ss.
    */
    format?: string;
}
